==> FWVirusScanner-1.4.tar.gz: FWVirusScanner-1.4/install.sh <==
#!/bin/bash
#     Copyright (C) 2005 Stewart Adam
#    This file is part of FWVirusScanner.

#    FWVirusScanner is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    FWVirusScanner is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with FWVirusScanner; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
which zenity
zen=$(echo $?)
which clamscan
clamscan=$(echo $?)
which php
php=$(echo $?)
check="0"

if [ "$zen" != "0" ]
then
check="1"
fi

if [ "$clamscan" != "0" ]
then
check="1"
fi

if [ "$php" != "0" ]
then
check="1"
fi

if [ "$check" == "0" ]
	then
	touch /root/abc123cba321
	trigger=$(echo $?)
	if [ "$trigger" != "0" ]
	then
		echo "Install failed. Make sure you are root."
		exit
	else
		rm /root/abc123cba321
	fi
	echo "Copying virus scanner, vs..."
	cp ./files/vs /usr/bin/vs
	cp ./files/vs /usr/sbin/vsroot
	echo "Making directory..."
	mkdir /usr/bin/vsdep
	echo "Copying sub-virus scanner, vsdep/arg..."
	cp ./files/vsdep/arg /usr/bin/vsdep/
	echo "Copying GUI to freshclam, updatevdb..."
	cp ./files/vsdep/arg /usr/bin/vsdep/
	echo "Linking..."
	ln -s /usr/bin/consolehelper /usr/bin/updatevdb
	ln -s /usr/bin/consolehelper /usr/bin/vsroot
	cp ./files/etc/security/console.apps/* /etc/security/console.apps/
	cp ./files/etc/pam.d/* /etc/pam.d/
	echo "Adding Desktop Menu Entries..."
	cp -a ./files/usr/share/applications/* /usr/share/applications
echo "Done."
else
	echo "Install failed. Make sure you are root."
fi

==> FWVirusScanner-1.5.tar.gz: FWVirusScanner-1.5/install.sh <==
#!/bin/bash
#     Copyright (C) 2005, 2006 Stewart Adam
#    This file is part of FWVirusScanner.

#    FWVirusScanner is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    FWVirusScanner is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with FWVirusScanner; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
which zenity
zen=$(echo $?)
which clamscan
clamscan=$(echo $?)
which php
php=$(echo $?)
check="0"

if [ "$zen" != "0" ]
then
check="1"
fi

if [ "$clamscan" != "0" ]
then
check="1"
fi

if [ "$php" != "0" ]
then
check="1"
fi

if [ "$check" == "0" ]
	then
	ROOT_UID=0   # Root has $UID 0.
	# Checks to see if user is running as root
	if [ "$UID" != "$ROOT_UID" ];then
		echo "Uninstall failed. Make sure you are root."
		exit 1
	fi
	echo "Installing virus scanner, vs..."
	cp ./files/usr/bin/vs /usr/bin/vs
	cp ./files/usr/bin/vs /usr/sbin/vsroot
	echo "Making directories..."
	mkdir /usr/bin/vsdep
	mkdir /var/log/clamav --parents
	echo "Installing virus scanner (2), vsdep/arg..."
	cp ./files/vsdep/arg /usr/bin/vsdep/
	echo "Installing GUI, updatevdb..."
	cp ./files/vsdep/arg /usr/bin/vsdep/
	echo "Linking..."
	ln -s /usr/bin/consolehelper /usr/bin/updatevdb
	ln -s /usr/bin/consolehelper /usr/bin/vsroot
	cp ./files/etc/security/console.apps/* /etc/security/console.apps/
	cp ./files/etc/pam.d/* /etc/pam.d/
	echo "Adding Desktop Menu Entries..."
	cp -a ./files/usr/share/applications/* /usr/share/applications
	echo "Setting File Permissions..."
	chmod +x /usr/bin/vsdep -R
	chmod +x /usr/bin/vs
	chmod +x /usr/sbin/vsroot
	chmod 777 /var/log/clamav
	echo "Done."
else
	echo -e "Install failed. Make sure you are root, and you have all dependencies:
gnome-utils = / > 2.10\n
php = / > 5.0.4\n
clamav (any)\n
installed."
fi
